@@ -1,6 +1,5 @@
 use crate::compress::optimize::unused::UnreachableHandler;
 use crate::compress::optimize::Optimizer;
-use swc_common::Spanned;
 use swc_common::DUMMY_SP;
 use swc_ecma_ast::*;
 use swc_ecma_transforms_base::ext::MapWithMut;
@@ -9,45 +8,6 @@ use swc_ecma_utils::Value::Known;
 
 /// Methods related to the option `loops`.
 impl Optimizer<'_> {
-    ///
-    /// - `while(test);` => `for(;;test);
-    /// - `do; while(true)` => `for(;;);
-    pub(super) fn loop_to_for_stmt(&mut self, s: &mut Stmt) {
-        if !self.options.loops {
-            return;
-        }
-
-        match s {
-            Stmt::While(stmt) => {
-                self.changed = true;
-                log::debug!("loops: Converting a while loop to a for loop");
-                *s = Stmt::For(ForStmt {
-                    span: stmt.span,
-                    init: None,
-                    test: Some(stmt.test.take()),
-                    update: None,
-                    body: stmt.body.take(),
-                });
-            }
-            Stmt::DoWhile(stmt) => {
-                let val = stmt.test.as_pure_bool();
-                if let Known(true) = val {
-                    self.changed = true;
-                    log::debug!("loops: Converting an always-true do-while loop to a for loop");
-
-                    *s = Stmt::For(ForStmt {
-                        span: stmt.span,
-                        init: None,
-                        test: Some(stmt.test.take()),
-                        update: None,
-                        body: stmt.body.take(),
-                    });
-                }
-            }
-            _ => {}
-        }
-    }
-
     /// `for(a;b;c;) break;` => `a;b;`
     pub(super) fn optimize_loops_with_break(&mut self, s: &mut Stmt) {
         if !self.options.loops {
@@ -98,70 +58,6 @@ impl Optimizer<'_> {
         *s = Stmt::Empty(EmptyStmt { span: DUMMY_SP })
     }
 
-    /// # Input
-    ///
-    /// ```js
-    /// for(; size--;)
-    ///     if (!(result = eq(a[size], b[size], aStack, bStack)))
-    ///         break;
-    /// ```
-    ///
-    ///
-    /// # Output
-    ///
-    /// ```js
-    /// for (; size-- && (result = eq(a[size], b[size], aStack, bStack)););
-    /// ```
-    pub(super) fn merge_for_if_break(&mut self, s: &mut ForStmt) {
-        match &mut *s.body {
-            Stmt::If(IfStmt {
-                test,
-                cons,
-                alt: None,
-                ..
-            }) => {
-                match &**cons {
-                    Stmt::Break(BreakStmt { label: None, .. }) => {
-                        // We only care about instant breaks.
-                        //
-                        // Note: As the minifier of swc is very fast, we don't
-                        // care about block statements with a single break as a
-                        // body.
-                        //
-                        // If it's optimizable, other pass for if statements
-                        // will remove block and with the next pass we can apply
-                        // this pass.
-                        self.changed = true;
-                        log::debug!("loops: Compressing for-if-break into a for statement");
-
-                        // We negate because this `test` is used as a condition for `break`.
-                        self.negate(test);
-
-                        match s.test.take() {
-                            Some(left) => {
-                                s.test = Some(Box::new(Expr::Bin(BinExpr {
-                                    span: s.test.span(),
-                                    op: op!("&&"),
-                                    left,
-                                    right: test.take(),
-                                })));
-                            }
-                            None => {
-                                s.test = Some(test.take());
-                            }
-                        }
-
-                        // Remove body
-                        s.body.take();
-                    }
-                    _ => {}
-                }
-            }
-
-            _ => {}
-        }
-    }
-
     ///
     /// - `while(false) { var a; foo() }` => `var a;`
     pub(super) fn optiimze_loops_if_cond_is_false(&mut self, stmt: &mut Stmt) {
