@@ -819,6 +819,27 @@ impl Optimizer<'_> {
 
     /// Returns true if something is modified.
     fn merge_sequential_expr(&mut self, a: &mut Mergable, b: &mut Expr) -> bool {
+        match a {
+            Mergable::Var(..) => {}
+            Mergable::Expr(a) => match a {
+                Expr::Seq(a) => {
+                    //
+                    for a in a.exprs.iter_mut().rev() {
+                        if self.merge_sequential_expr(&mut Mergable::Expr(a), b) {
+                            return true;
+                        }
+
+                        if !self.is_skippable_for_seq(&a) {
+                            return false;
+                        }
+                    }
+
+                    return false;
+                }
+                _ => {}
+            },
+        }
+
         match b {
             Expr::Update(..) => return false,
 
@@ -1153,7 +1174,6 @@ impl Optimizer<'_> {
                             Some(v) => v,
                             None => {
                                 log::trace!("[X] sequences: Aborting because lhs is not an id");
-
                                 return false;
                             }
                         };
@@ -1164,6 +1184,11 @@ impl Optimizer<'_> {
                             .and_then(|data| data.vars.get(&left_id.to_id()))
                         {
                             if usage.declared_as_fn_expr {
+                                log::trace!(
+                                    "sequences: [X] Declared as fn expr ({}, {:?})",
+                                    left_id.sym,
+                                    left_id.span.ctxt
+                                );
                                 return false;
                             }
                         }
