@@ -1,4 +1,4 @@
-use crate::option::CompressOptions;
+use crate::{option::CompressOptions, DISABLE_BUGGY_PASSES};
 use swc_ecma_ast::*;
 use swc_ecma_transforms_base::ext::MapWithMut;
 use swc_ecma_visit::{noop_visit_mut_type, VisitMut, VisitMutWith};
@@ -16,6 +16,10 @@ impl PostcompressOptimizer<'_> {
         if !self.options.bools {
             return;
         }
+        // This is buggy
+        if DISABLE_BUGGY_PASSES {
+            return;
+        }
 
         // Note: `||` is not handled because of precedence.
         match e {
